pub struct AllocationInfo2 {
pub allocation_info: AllocationInfo,
pub block_size: u64,
pub dedicated_memory: bool,
}Expand description
Extended parameters of a VmaAllocation object that can be retrieved using Allocation::get_allocation_info2.
Fields
allocation_info: AllocationInfoBasic parameters of the allocation.
If you need only these, you can use function vmaGetAllocationInfo() and structure #VmaAllocationInfo instead.
block_size: u64Size of the VkDeviceMemory block that the allocation belongs to.
In case of an allocation with dedicated memory, it will be equal to allocationInfo.size.
dedicated_memory: booltrue if the allocation has dedicated memory, false if it was placed as part of a larger memory block.
When true, it also means VkMemoryDedicatedAllocateInfo was used when creating the allocation
(if VK_KHR_dedicated_allocation extension or Vulkan version >= 1.1 is enabled).