[−][src]Struct vk_mem::Allocation
Represents single memory allocation.
It may be either dedicated block of ash::vk::DeviceMemory or a specific region of a
bigger block of this type plus unique offset.
Although the library provides convenience functions that create a Vulkan buffer or image, allocate memory for it and bind them together, binding of the allocation to a buffer or an image is out of scope of the allocation itself.
Allocation object can exist without buffer/image bound, binding can be done manually by the user, and destruction of it can be done independently of destruction of the allocation.
The object also remembers its size and some other information. To retrieve this information,
use Allocator::get_allocation_info.
Some kinds allocations can be in lost state.
Methods
impl Allocation[src]
pub fn null() -> Allocation[src]